niftiInfoR6: Class with file information of NIfTI files

Description Usage Format Value Fields Methods Examples

Description

Class with file information of NIfTI files

Usage

1

Format

R6Class object.

Value

Object of R6Class with information on a NIfTI file

Fields

fullpath

Full path of the file

filename

Name of the file (without extension)

extension

Extension of the file

gzipped

Is the file compressed?

endian

Endianness of the file

data.type

Type of data in file

data.signed

Are data.type signed?

connection

Connection to the file

Methods

getFullPath()

Returns string of path to the file.

changeName()

Changes the name of the file in the R6 object.

changePath()

Changes the path of the file in the R6 object.

getName()

Returns string of the filename.

showInfo()

Shows the info of the file.

Examples

1
niftiInfo <- niftiInfoR6$new()

wdweeda/niftiR6 documentation built on Jan. 31, 2022, 5:09 p.m.