Description Usage Format Value Fields Methods Examples
Class with file information of NIfTI files
1 |
R6Class object.
Object of R6Class with information on a NIfTI file
fullpathFull path of the file
filenameName of the file (without extension)
extensionExtension of the file
gzippedIs the file compressed?
endianEndianness of the file
data.typeType of data in file
data.signedAre data.type signed?
connectionConnection to the file
getFullPath()Returns string of path to the file.
changeName()Changes the name of the file in the R6 object.
changePath()Changes the path of the file in the R6 object.
getName()Returns string of the filename.
showInfo()Shows the info of the file.
1 | niftiInfo <- niftiInfoR6$new()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.